/**
 * Adyen Checkout Service
 * Adyen Checkout API provides a simple and flexible way to initiate and authorise online payments. You can use the same integration for payments made with cards (including One-Click and 3D Secure), mobile wallets, and local payment methods (e.g. iDEAL and Sofort).  This API reference provides information on available endpoints and how to interact with them. To learn more about the API, visit [Checkout documentation](https://docs.adyen.com/checkout).  ## Authentication Each request to the Checkout API must be signed with an API key. For this, obtain an API Key from your Customer Area, as described in [How to get the API key](https://docs.adyen.com/user-management/how-to-get-the-api-key). Then set this key to the `X-API-Key` header value, for example:  ``` curl -H \"Content-Type: application/json\" \\ -H \"X-API-Key: Your_Checkout_API_key\" \\ ... ``` Note that when going live, you need to generate a new API Key to access the [live endpoints](https://docs.adyen.com/development-resources/live-endpoints).  ## Versioning Checkout API supports versioning of its endpoints through a version suffix in the endpoint URL. This suffix has the following format: \"vXX\", where XX is the version number.  For example: ``` https://checkout-test.adyen.com/v46/payments ```
 *
 * OpenAPI spec version: 46
 * Contact: support@adyen.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
export interface AccountInfo {
    /**
     * Indicator for the length of time since this shopper account was created in the merchant's environment. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
     */
    accountAgeIndicator?: AccountInfo.AccountAgeIndicatorEnum;
    /**
     * Date when the shopper's account was last changed.
     */
    accountChangeDate?: Date;
    /**
     * Indicator for the length of time since the shopper's account was last updated. Allowed values: * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
     */
    accountChangeIndicator?: AccountInfo.AccountChangeIndicatorEnum;
    /**
     * Date when the shopper's account was created.
     */
    accountCreationDate?: Date;
    /**
     * Number of attempts the shopper tried to add a card to their account in the last day.
     */
    addCardAttemptsDay?: number;
    /**
     * Date the selected delivery address was last used.
     */
    deliveryAddressUsageDate?: Date;
    /**
     * Indicator for the length of time since this delivery address was last used. Allowed values: * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
     */
    deliveryAddressUsageIndicator?: AccountInfo.DeliveryAddressUsageIndicatorEnum;
    /**
     * Shopper's home phone number (including the country code).
     */
    homePhone?: string;
    /**
     * Shopper's mobile phone number (including the country code).
     */
    mobilePhone?: string;
    /**
     * Date when the shopper last changed their password.
     */
    passwordChangeDate?: Date;
    /**
     * Indicator when the shopper has changed their password. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
     */
    passwordChangeIndicator?: AccountInfo.PasswordChangeIndicatorEnum;
    /**
     * Number of all transactions (successful and abandoned) from this shopper in the past 24 hours.
     */
    pastTransactionsDay?: number;
    /**
     * Number of all transactions (successful and abandoned) from this shopper in the past year.
     */
    pastTransactionsYear?: number;
    /**
     * Date this payment method was added to the shopper's account.
     */
    paymentAccountAge?: Date;
    /**
     * Indicator for the length of time since this payment method was added to this shopper's account. Allowed values: * notApplicable * thisTransaction * lessThan30Days * from30To60Days * moreThan60Days
     */
    paymentAccountIndicator?: AccountInfo.PaymentAccountIndicatorEnum;
    /**
     * Number of successful purchases in the last six months.
     */
    purchasesLast6Months?: number;
    /**
     * Whether suspicious activity was recorded on this account.
     */
    suspiciousActivity?: boolean;
    /**
     * Shopper's work phone number (including the country code).
     */
    workPhone?: string;
}
export declare namespace AccountInfo {
    type AccountAgeIndicatorEnum = 'notApplicable' | 'thisTransaction' | 'lessThan30Days' | 'from30To60Days' | 'moreThan60Days';
    const AccountAgeIndicatorEnum: {
        NotApplicable: AccountAgeIndicatorEnum;
        ThisTransaction: AccountAgeIndicatorEnum;
        LessThan30Days: AccountAgeIndicatorEnum;
        From30To60Days: AccountAgeIndicatorEnum;
        MoreThan60Days: AccountAgeIndicatorEnum;
    };
    type AccountChangeIndicatorEnum = 'thisTransaction' | 'lessThan30Days' | 'from30To60Days' | 'moreThan60Days';
    const AccountChangeIndicatorEnum: {
        ThisTransaction: AccountChangeIndicatorEnum;
        LessThan30Days: AccountChangeIndicatorEnum;
        From30To60Days: AccountChangeIndicatorEnum;
        MoreThan60Days: AccountChangeIndicatorEnum;
    };
    type DeliveryAddressUsageIndicatorEnum = 'thisTransaction' | 'lessThan30Days' | 'from30To60Days' | 'moreThan60Days';
    const DeliveryAddressUsageIndicatorEnum: {
        ThisTransaction: AccountChangeIndicatorEnum;
        LessThan30Days: AccountChangeIndicatorEnum;
        From30To60Days: AccountChangeIndicatorEnum;
        MoreThan60Days: AccountChangeIndicatorEnum;
    };
    type PasswordChangeIndicatorEnum = 'notApplicable' | 'thisTransaction' | 'lessThan30Days' | 'from30To60Days' | 'moreThan60Days';
    const PasswordChangeIndicatorEnum: {
        NotApplicable: AccountAgeIndicatorEnum;
        ThisTransaction: AccountAgeIndicatorEnum;
        LessThan30Days: AccountAgeIndicatorEnum;
        From30To60Days: AccountAgeIndicatorEnum;
        MoreThan60Days: AccountAgeIndicatorEnum;
    };
    type PaymentAccountIndicatorEnum = 'notApplicable' | 'thisTransaction' | 'lessThan30Days' | 'from30To60Days' | 'moreThan60Days';
    const PaymentAccountIndicatorEnum: {
        NotApplicable: AccountAgeIndicatorEnum;
        ThisTransaction: AccountAgeIndicatorEnum;
        LessThan30Days: AccountAgeIndicatorEnum;
        From30To60Days: AccountAgeIndicatorEnum;
        MoreThan60Days: AccountAgeIndicatorEnum;
    };
}
